@@ -25,16 +25,16 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E\N{U+060c} d/M",
+    MEd => "E\N{U+060c} d/\N{U+200f}M",
     MMM => "LLL",
     MMMEd => "E\N{U+060c} d MMM",
     MMMMEd => "E\N{U+060c} d MMMM",
-    "MMMMW-count-few" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
-    "MMMMW-count-many" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
-    "MMMMW-count-one" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
-    "MMMMW-count-other" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
-    "MMMMW-count-two" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
-    "MMMMW-count-zero" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMM",
+    "MMMMW-count-few" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
+    "MMMMW-count-many" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
+    "MMMMW-count-one" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
+    "MMMMW-count-other" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
+    "MMMMW-count-two" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
+    "MMMMW-count-zero" => "\N{U+0627}\N{U+0644}\N{U+0623}\N{U+0633}\N{U+0628}\N{U+0648}\N{U+0639} W \N{U+0645}\N{U+0646} MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd\N{U+200f}/MM",
@@ -69,10 +69,10 @@
   date_format_long => "d MMMM y",
   date_format_medium => "dd\N{U+200f}/MM\N{U+200f}/y",
   date_format_short => "d\N{U+200f}/M\N{U+200f}/y",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_full => "{1} \N{U+0641}\N{U+064a} {0}",
+  datetime_format_long => "{1} \N{U+0641}\N{U+064a} {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "\N{U+0627}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0646}\N{U+064a}\N{U+0646}",
     "\N{U+0627}\N{U+0644}\N{U+062b}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0627}\N{U+0621}",
@@ -140,11 +140,11 @@
     "\N{U+0645}\N{U+064a}\N{U+0644}\N{U+0627}\N{U+062f}\N{U+064a}",
   ],
   first_day_of_week => 6,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%d %b, %Y %Z %I:%M:%S %p",
   glibc_date_format => "%d %b, %Y",
-  glibc_datetime_format => "%d %b, %Y %Z %I:%M:%S %p",
+  glibc_datetime_format => "%d %b, %Y %I:%M:%S %p",
   glibc_time_12_format => "%Z %I:%M:%S %p",
-  glibc_time_format => "%Z %I:%M:%S ",
+  glibc_time_format => "%Z %I:%M:%S %p",
   language => "Arabic",
   month_format_abbreviated => [
     "\N{U+064a}\N{U+0646}\N{U+0627}\N{U+064a}\N{U+0631}",
@@ -279,5 +279,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 32,
+  version => 38,
 }
