@@ -28,14 +28,16 @@
     MEd => "E, dd.MM.",
     MMM => "LLL",
     MMMEd => "E, dd. MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
-    MMMMd => "MMMM d",
+    "MMMMW-count-few" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' W '\N{U+043c}\N{U+0458}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0446}' MMMM",
+    "MMMMW-count-one" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' W '\N{U+043c}\N{U+0458}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0446}' MMMM",
+    "MMMMW-count-other" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' W '\N{U+043c}\N{U+0458}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0446}' MMMM",
+    MMMMd => "d. MMMM",
     MMMd => "dd. MMM",
     Md => "dd.MM.",
     d => "d",
-    h => "hh a",
-    hm => "hh:mm a",
-    hms => "hh:mm:ss a",
+    h => "h a",
+    hm => "h:mm a",
+    hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
@@ -44,12 +46,14 @@
     yMEd => "E, dd.MM.y.",
     yMMM => "MMM y.",
     yMMMEd => "E, dd. MMM y.",
-    yMMMM => "y MMMM",
+    yMMMM => "MMMM y.",
     yMMMd => "dd. MMM y.",
     yMd => "dd.MM.y.",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-few" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' w '\N{U+0433}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+043d}\N{U+0430}' Y",
+    "yw-count-one" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' w '\N{U+0433}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+043d}\N{U+0430}' Y",
+    "yw-count-other" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' w '\N{U+0433}\N{U+043e}\N{U+0434}\N{U+0438}\N{U+043d}\N{U+0430}' Y",
   },
   code => "bs-Cyrl",
   date_format_full => "EEEE, dd. MMMM y.",
@@ -266,5 +270,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 38,
 }
