@@ -134,9 +134,9 @@
     "n. Chr.",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
   glibc_date_format => "%Y-%m-%d",
-  glibc_datetime_format => "%a %d %b %Y %T %Z",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%T",
   language => "German",
@@ -273,5 +273,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 37,
+  version => 38,
 }
