@@ -263,10 +263,10 @@
   ],
   script => undef,
   territory => "Burundi",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "HH:mm:ss zzzz",
+  time_format_long => "HH:mm:ss z",
+  time_format_medium => "HH:mm:ss",
+  time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 38,
 }
