@@ -53,12 +53,12 @@
     yM => "M/y",
     yMEd => "E, d/M/y",
     yMM => "MM/y",
-    yMMM => "MMMM 'de' y",
-    yMMMEd => "EEE, d 'de' MMMM 'de' y",
+    yMMM => "MMM 'de' y",
+    yMMMEd => "EEE, d 'de' MMM 'de' y",
     yMMMM => "MMMM 'de' y",
     yMMMMEd => "EEE, d 'de' MMMM 'de' y",
     yMMMMd => "d 'de' MMMM 'de' y",
-    yMMMd => "d 'de' MMMM 'de' y",
+    yMMMd => "d 'de' MMM 'de' y",
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ 'de' y",
@@ -75,13 +75,13 @@
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
-    "lun.",
-    "mar.",
-    "mi\N{U+00e9}.",
-    "jue.",
-    "vie.",
-    "s\N{U+00e1}b.",
-    "dom.",
+    "lun",
+    "mar",
+    "mi\N{U+00e9}",
+    "jue",
+    "vie",
+    "s\N{U+00e1}b",
+    "dom",
   ],
   day_format_narrow => [
     "L",
@@ -141,9 +141,9 @@
     "despu\N{U+00e9}s de Cristo",
   ],
   first_day_of_week => 7,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
   glibc_date_format => "%d/%m/%y",
-  glibc_datetime_format => "%a %d %b %Y %T %Z",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%T",
   language => "Spanish",
@@ -238,40 +238,40 @@
   native_territory => "Estados Unidos",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "1er. trim.",
-    "2\N{U+00ba}. trim.",
-    "3er. trim.",
-    "4\N{U+00ba} trim.",
+    "T1",
+    "T2",
+    "T3",
+    "T4",
   ],
   quarter_format_narrow => [
-    "1T",
-    "2T",
-    "3T",
-    "4T",
+    1,
+    2,
+    3,
+    4,
   ],
   quarter_format_wide => [
     "1.er trimestre",
-    "2\N{U+00ba}. trimestre",
+    "2.\N{U+00ba} trimestre",
     "3.er trimestre",
-    "4o. trimestre",
+    "4.\N{U+00ba} trimestre",
   ],
   quarter_stand_alone_abbreviated => [
-    "1er. trim.",
-    "2\N{U+00ba}. trim.",
-    "3er. trim.",
-    "4\N{U+00ba} trim.",
+    "T1",
+    "T2",
+    "T3",
+    "T4",
   ],
   quarter_stand_alone_narrow => [
-    "1T",
-    "2T",
-    "3T",
-    "4T",
+    1,
+    2,
+    3,
+    4,
   ],
   quarter_stand_alone_wide => [
     "1.er trimestre",
     "2\N{U+00ba}. trimestre",
     "3.er trimestre",
-    "4\N{U+00ba} trimestre",
+    "4.\N{U+00ba} trimestre",
   ],
   script => undef,
   territory => "United States",
@@ -280,5 +280,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 37,
+  version => 38,
 }
