@@ -29,7 +29,7 @@
     MMM => "LLL",
     MMMEd => "E, d. MMM",
     "MMMMW-count-other" => "'week' W 'of' MMMM",
-    MMMMd => "MMMM d",
+    MMMMd => "d MMMM",
     MMMd => "d. MMM",
     Md => "d.M.",
     d => "d",
@@ -44,7 +44,7 @@
     yMEd => "E, d.M.y",
     yMMM => "MMM y",
     yMMMEd => "E, d. MMM y",
-    yMMMM => "y MMMM",
+    yMMMM => "LLLL y",
     yMMMd => "d. MMM y",
     yMd => "d.M.y",
     yQQQ => "QQQ y",
@@ -266,5 +266,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm 'hod\N{U+017a}'.",
   variant => undef,
-  version => 35,
+  version => 38,
 }
