@@ -8,15 +8,15 @@
     Bhm => "h:mm B",
     Bhms => "h:mm:ss B",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E, h:mm B",
+    EBhms => "E, h:mm:ss B",
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E, d",
     Ehm => "E, h:mm a",
     Ehms => "E, h:mm:ss a",
     Gy => "y G",
-    GyMMM => "MMM y G",
+    GyMMM => "LLL y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
     H => "HH",
@@ -29,7 +29,7 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d 'di' MMMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-other" => "W'\N{U+00ba}' 'simana' 'di' MMMM",
     MMMMd => "d 'di' MMMM",
     MMMd => "d MMM",
     MMdd => "dd/MM",
@@ -43,27 +43,27 @@
     mmss => "mm:ss",
     ms => "mm:ss",
     y => "y",
-    yM => "MM/y",
+    yM => "LL/y",
     yMEd => "E, dd/MM/y",
-    yMM => "MM/y",
-    yMMM => "MMM y",
+    yMM => "LL/y",
+    yMMM => "LLL y",
     yMMMEd => "E, d MMM y",
-    yMMMM => "MMMM 'di' y",
+    yMMMM => "LLLL 'di' y",
     yMMMd => "d MMM y",
     yMd => "dd/MM/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ 'di' y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-other" => "w'\N{U+00ba}' 'simana' 'di' Y",
   },
   code => "kea",
   date_format_full => "EEEE, d 'di' MMMM 'di' y",
   date_format_long => "d 'di' MMMM 'di' y",
   date_format_medium => "d MMM y",
-  date_format_short => "d/M/y",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  date_format_short => "dd/MM/y",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "sig",
     "ter",
@@ -88,7 +88,7 @@
     "kuarta-fera",
     "kinta-fera",
     "sesta-fera",
-    "sabadu",
+    "s\N{U+00e1}badu",
     "dumingu",
   ],
   day_stand_alone_abbreviated => [
@@ -127,8 +127,8 @@
     "DK",
   ],
   era_wide => [
-    "Antis di Kristu",
-    "Dispos di Kristu",
+    "antis di Kristu",
+    "dispos di Kristu",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -270,5 +270,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 38,
 }
