@@ -133,9 +133,9 @@
     "m\N{U+016b}su \N{U+0113}r\N{U+0101}",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%A, %Y. gada %e. %B, %H:%M:%S %Z",
   glibc_date_format => "%Y.%m.%d.",
-  glibc_datetime_format => "%A, %Y. gada %e. %B, plkst. %H un %M",
+  glibc_datetime_format => "%A, %Y. gada %e. %B, %H:%M:%S",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%T",
   language => "Latvian",
@@ -272,5 +272,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 37,
+  version => 38,
 }
