@@ -29,9 +29,9 @@
     MMM => "LLL",
     MMMEd => "E d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-few" => "W. 'sedmica' 'u' MMM.",
-    "MMMMW-count-one" => "W. 'sedmica' 'u' MMM.",
-    "MMMMW-count-other" => "W. 'sedmica' 'u' MMM.",
+    "MMMMW-count-few" => "W. 'sedmica' 'u' MMMM.",
+    "MMMMW-count-one" => "W. 'sedmica' 'u' MMMM.",
+    "MMMMW-count-other" => "W. 'sedmica' 'u' MMMM.",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMMdd => "dd.MMM",
@@ -136,7 +136,7 @@
     "nove ere",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a<U002c> %e. %b %Y.  %H:%M:%S %Z\n",
+  glibc_date_1_format => "%a, %e. %b %Y.  %H:%M:%S %Z",
   glibc_date_format => "%d.%m.%Y.",
   glibc_datetime_format => "%A, %d. %B %Y. %T %Z",
   glibc_time_12_format => "%T",
@@ -275,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 38,
 }
