@@ -70,13 +70,13 @@
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
-    "pon.",
-    "ut.",
-    "sr.",
-    "\N{U+010d}et.",
-    "pet.",
-    "sub.",
-    "ned.",
+    "pon",
+    "uto",
+    "sre",
+    "\N{U+010d}et",
+    "pet",
+    "sub",
+    "ned",
   ],
   day_format_narrow => [
     "p",
@@ -97,13 +97,13 @@
     "nedelja",
   ],
   day_stand_alone_abbreviated => [
-    "pon.",
-    "ut.",
-    "sr.",
-    "\N{U+010d}et.",
-    "pet.",
-    "sub.",
-    "ned.",
+    "pon",
+    "uto",
+    "sre",
+    "\N{U+010d}et",
+    "pet",
+    "sub",
+    "ned",
   ],
   day_stand_alone_narrow => [
     "p",
@@ -143,18 +143,18 @@
   glibc_time_format => "%H:%M:%S",
   language => "Serbian",
   month_format_abbreviated => [
-    "jan.",
-    "feb.",
+    "jan",
+    "feb",
     "mart",
-    "apr.",
+    "apr",
     "maj",
     "jun",
     "jul",
-    "avg.",
-    "sept.",
-    "okt.",
-    "nov.",
-    "dec.",
+    "avg",
+    "sept",
+    "okt",
+    "nov",
+    "dec",
   ],
   month_format_narrow => [
     "j",
@@ -185,18 +185,18 @@
     "decembar",
   ],
   month_stand_alone_abbreviated => [
-    "jan.",
-    "feb.",
+    "jan",
+    "feb",
     "mart",
-    "apr.",
+    "apr",
     "maj",
     "jun",
     "jul",
-    "avg.",
-    "sept.",
-    "okt.",
-    "nov.",
-    "dec.",
+    "avg",
+    "sept",
+    "okt",
+    "nov",
+    "dec",
   ],
   month_stand_alone_narrow => [
     "j",
@@ -275,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 38,
 }
